package fr.sanchezm.attestationsCovid19.ui.attestations

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.databinding.DataBindingUtil
import androidx.fragment.app.Fragment
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import androidx.recyclerview.widget.LinearLayoutManager
import fr.sanchezm.attestationsCovid19.PdfViewerActivity
import fr.sanchezm.attestationsCovid19.QrCodeActivity
import fr.sanchezm.attestationsCovid19.R
import fr.sanchezm.attestationsCovid19.data.db.entity.Attestation
import fr.sanchezm.attestationsCovid19.databinding.FragmentAttestationsBinding
import fr.sanchezm.attestationsCovid19.interfaces.ItemClickListener
import fr.sanchezm.attestationsCovid19.utilities.InjectorUtils
import kotlinx.android.synthetic.main.fragment_attestations.view.*

class AttestationsFragment : Fragment() {

    private lateinit var attestationsViewModel: AttestationsViewModel
    private val attestationsAdapter = AttestationsAdapter(arrayListOf(),
        object : ItemClickListener {
            override fun onItemClick(item: Attestation) {
                val intent = Intent(context, QrCodeActivity::class.java).apply {
                    putExtra("createAt", item.createAt)
                    putExtra("toCreate", false)
                }
                startActivity(intent)
            }
        })

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        initializeUi()
        val binding = DataBindingUtil.inflate<FragmentAttestationsBinding>(
            inflater,
            R.layout.fragment_attestations,
            container,
            false
        ).apply {
            this.lifecycleOwner = this@AttestationsFragment
            this.viewModel = attestationsViewModel
        }

        binding.root.attestation_recycler_view.apply {
            layoutManager = LinearLayoutManager(context)
            adapter = attestationsAdapter
        }
        bindMessage()
        return binding.root
    }

    private fun bindMessage() {
        attestationsViewModel.startActivity.observe(viewLifecycleOwner, Observer { event ->
            event.getContentIfNotHandled()?.let { createAtPdf ->
                val intent = Intent(context, PdfViewerActivity::class.java).apply {
                    putExtra("createAt", createAtPdf)
                }
                startActivity(intent)
            }
        })

        attestationsViewModel.attestations.observe(viewLifecycleOwner, Observer {
            attestationsAdapter.updateAttestations(it)
        })
    }

    private fun initializeUi() {
        val factory = context?.let { InjectorUtils.provideAttestationViewModel(it) }
        attestationsViewModel = factory?.let {
            ViewModelProvider(this, it)
                .get(AttestationsViewModel::class.java)
        }!!
    }
}